@@ -1,5 +1,12 @@
 var waitMessage = '<div class="row mb-4"><div class="col-md-4 offset-md-4"><div class="progress"><div class="progress-bar progress-bar-striped" style="width: 100%;">Please wait ...</div></div></div></div>';
 
+var multiselectOptions = {
+  templates: {
+    button: '<button type="button" class="multiselect dropdown-toggle border-secondary" data-toggle="dropdown"><span class="multiselect-selected-text"></span> <b class="caret"></b></button>',
+    li: '<li class="dropdown-item"><a href="javascript:void(0);"><label></label></a></li>'
+  }
+};
+
 /*
  * Load instance properties using /json/settings/instance API
  * and build the update form.
@@ -37,7 +44,7 @@ function load_update_instance_form(modal_id, agent_address, agent_port)
       body_html += '  <div class="row">';
       body_html += '    <div class="form-group col-sm-12">';
       body_html += '      <label for="inputAgentKey" class="control-label">Agent secret key</label>';
-      body_html += '      <textarea class="form-control" rows="1" id="inputAgentKey">'+data['agent_key']+'</textarea>';
+      body_html += '      <input class="form-control" id="inputAgentKey" value="'+data['agent_key']+'">';
       body_html += '    </div>';
       body_html += '  </div>';
       body_html += '  <div class="row">';
@@ -82,6 +89,12 @@ function load_update_instance_form(modal_id, agent_address, agent_port)
       body_html += '      </div>';
       body_html += '    </div>';
       body_html += '  </div>';
+      body_html += '  <div class="row">';
+      body_html += '    <div class="form-group col-sm-12">';
+      body_html += '      <label for="inputComment" class="control-label">Comment</label>';
+      body_html += '      <textarea class="form-control" rows="3" id="inputComment">'+data['comment']+'</textarea>';
+      body_html += '    </div>';
+      body_html += '  </div>';
       body_html += '</form>';
       var footer_html = '';
       footer_html += '<i class="fa fa-spinner fa-spin loader d-none"></i>';
@@ -99,8 +112,8 @@ function load_update_instance_form(modal_id, agent_address, agent_port)
         }
       });
       // Activate multiselect plugin for group selecting.
-      $('#selectGroups').multiselect();
-      $('#selectPlugins').multiselect();
+      $('#selectGroups').multiselect(multiselectOptions);
+      $('#selectPlugins').multiselect(multiselectOptions);
       // Add group's description as a tooltip.
       $('.multiselect-container li').not('.filter, .group').tooltip({
       placement: 'right',
@@ -120,7 +133,8 @@ function load_update_instance_form(modal_id, agent_address, agent_port)
           $('#inputNewAgentAddress').val(),
           $('#inputNewAgentPort').val(),
           $('#inputAgentKey').val(),
-          $('#inputNotify').prop('checked')
+          $('#inputNotify').prop('checked'),
+          $('#inputComment').val()
         );
       });
     },
@@ -128,23 +142,23 @@ function load_update_instance_form(modal_id, agent_address, agent_port)
   });
 }
 
-function addInstance(modal_id, address, port, key, notify) {
+function addInstance(modal_id, address, port, key, notify, comment) {
   var url = '/json/settings/instance';
   var onSuccess = function (data) {
-    saveInstance(modal_id, url, address, port, key, notify, data);
+    saveInstance(modal_id, url, address, port, key, notify, comment, data);
   }
   var onError = showError.bind(null, modal_id);
   discoverInstance(modal_id, address, port, onSuccess, onError);
 }
 
-function updateInstance(modal_id, address, port, newAddress, newPort, key, notify) {
+function updateInstance(modal_id, address, port, newAddress, newPort, key, notify, comment) {
   var url = ['/json/settings/instance', address, port].join('/');
   var onSuccess = function (data) {
-    saveInstance(modal_id, url, address, port, key, notify, data);
+    saveInstance(modal_id, url, address, port, key, notify, comment, data);
   }
   var onError = function () {
     // save the instance anyway, without discovered data
-    saveInstance(modal_id, url, address, port, key, notify);
+    saveInstance(modal_id, url, address, port, key, notify, comment);
   }
   discoverInstance(modal_id, address, port, onSuccess, onError);
 }
@@ -162,14 +176,15 @@ function discoverInstance(modal_id, address, port, onSuccess, onError) {
   });
 }
 
-function saveInstance(modal_id, saveUrl, address, port, key, notify, discoverData) {
+function saveInstance(modal_id, saveUrl, address, port, key, notify, comment, discoverData) {
   var data = {
     'new_agent_address': address,
     'new_agent_port': port.toString(),
     'agent_key': key,
     'groups': $('#selectGroups').val(),
     'plugins': $('#selectPlugins').val(),
-    'notify': notify
+    'notify': notify,
+    'comment': comment
   };
 
   // add discovered data in case we managed to get it from the agent
@@ -311,7 +326,7 @@ function load_add_instance_form(modal_id)
       body_html += '  <div class="row">';
       body_html += '    <div class="form-group col-sm-12">';
       body_html += '      <label for="inputAgentKey" class="control-label">Agent secret key</label>';
-      body_html += '      <textarea class="form-control" rows="3" id="inputAgentKey"></textarea>';
+      body_html += '      <input class="form-control" id="inputAgentKey">';
       body_html += '    </div>';
       body_html += '  </div>';
       body_html += '  <div class="row">';
@@ -345,6 +360,12 @@ function load_add_instance_form(modal_id)
       body_html += '      </div>';
       body_html += '    </div>';
       body_html += '  </div>';
+      body_html += '  <div class="row">';
+      body_html += '    <div class="form-group col-sm-12">';
+      body_html += '      <label for="inputComment" class="control-label">Comment</label>';
+      body_html += '      <textarea class="form-control" rows="3" id="inputComment"></textarea>';
+      body_html += '    </div>';
+      body_html += '  </div>';
       body_html += '</form>';
       var footer_html = '';
       footer_html += '<i class="fa fa-spinner fa-spin loader d-none"></i>';
@@ -358,8 +379,8 @@ function load_add_instance_form(modal_id)
         $('#formAddInstance').submit()
       });
       // Activate multiselect plugin for group selecting.
-      $('#selectGroups').multiselect();
-      $('#selectPlugins').multiselect();
+      $('#selectGroups').multiselect(multiselectOptions);
+      $('#selectPlugins').multiselect(multiselectOptions);
       // Add group's description as a tooltip.
       $('.multiselect-container li').not('.filter, .group').tooltip({
           placement: 'right',
@@ -376,7 +397,8 @@ function load_add_instance_form(modal_id)
           $('#inputNewAgentAddress').val(),
           $('#inputNewAgentPort').val(),
           $('#inputAgentKey').val(),
-          $('#inputNotify').prop('checked')
+          $('#inputNotify').prop('checked'),
+          $('#inputComment').val()
         );
       });
     },
